@@ -22,7 +22,7 @@ package Net::FullAuto::ISets::Amazon::KaliLinux_is;
 #######################################################################
 
 
-our $VERSION='0.01';
+our $VERSION='0.02';
 our $DISPLAY='Kali Linux™';
 our $CONNECT='ssh';
 our $defaultInstanceType='t2.micro';
@@ -44,33 +44,32 @@ my $install_dashboard_on_kalilinux=sub {
    my $server_type=$_[0];
    my $cnt=$_[1];
    my $server_host_block=$_[2]||'';
-   my $handle=$main::aws->{$server_type}->[$cnt]->[1];
+   my $handle=$_[3];
    my ($stdout,$stderr,$hash,$error,$output)=('','','','',''); 
-   ($stdout,$stderr)=$handle->cmd("apt-get update",3600,'__display__');
    ($stdout,$stderr)=$handle->cmd(
-       "apt-get -o Dpkg::Progress=true -y install apache2",3600,
+       "sudo apt-get -o Dpkg::Progress=true -y install apache2",3600,
        '__display__');
-   ($stdout,$stderr)=$handle->cmd("sed -e 's/index.php //' ".
+   ($stdout,$stderr)=$handle->cmd("sudo sed -e 's/index.php //' ".
         "/etc/apache2/mods-enabled/dir.conf");
-   ($stdout,$stderr)=$handle->cmd("sed -e 's/Index/Index index.php/' ".
+   ($stdout,$stderr)=$handle->cmd("sudo sed -e 's/Index/Index index.php/' ".
         "/etc/apache2/mods-enabled/dir.conf");
-   ($stdout,$stderr)=$handle->cmd("service apache2 restart");
+   ($stdout,$stderr)=$handle->cmd("sudo service apache2 restart");
    ($stdout,$stderr)=$handle->cmd(
-      "apt-get -o Dpkg::Progress=true -y install git",3600,'__display__');
+      "sudo apt-get -o Dpkg::Progress=true -y install git",3600,'__display__');
    if ($stderr) {
       print "Kali Linux Instruction Set aws cmd ERROR!: $stderr at Line",
          __LINE__,"\n";
       Net::FullAuto::FA_Core::cleanup();
    }
-   ($stdout,$stderr)=$handle->cwd("/var/www");
-   ($stdout,$stderr)=$handle->cmd("git clone ".
+   ($stdout,$stderr)=$handle->cwd("/var/www/html");
+   ($stdout,$stderr)=$handle->cmd("sudo git clone ".
        "https://github.com/afaqurk/linux-dash.git 2>&1",
        '__display__');
    ($stdout,$stderr)=$handle->cmd(
-       "apt-get -o Dpkg::Progress=true -y install php5 ".
+       "sudo apt-get -o Dpkg::Progress=true -y install php5 ".
        "libapache2-mod-php5 php5-mcrypt",3600,
        '__display__');
-   ($stdout,$stderr)=$handle->cmd("/usr/sbin/apache2ctl start",
+   ($stdout,$stderr)=$handle->cmd("sudo /usr/sbin/apache2ctl start",
       '__allow_no_output__');
    my $master=$main::aws->{$server_type}->[$cnt]->[0]->{InstanceId};
    my $c="aws ec2 describe-instances --instance-ids $master 2>&1";
@@ -117,17 +116,22 @@ my $configure_kalilinux=sub {
    my $server_host_block=$_[3]||'';
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my ($stdout,$stderr)=('','');
+   ($stdout,$stderr)=$handle->cmd("sudo apt-get update");
+   ($stdout,$stderr)=$handle->cmd("sudo apt-get -o Dpkg::Progress=true ".
+      "-y install build-essential",3600,'__display__');
+   ($stdout,$stderr)=$handle->cmd("sudo apt-get -o Dpkg::Progress=true ".
+      "-y install git",3600,'__display__'); 
+   ($stdout,$stderr)=$handle->cmd("sudo gpg --ignore-time-conflict ".
+      "--no-options --no-default-keyring --homedir /tmp/tmp.J6INeDB25r ".
+      "--no-auto-check-trustdb --trust-model always --keyring ".
+      "/etc/apt/trusted.gpg --primary-keyring /etc/apt/trusted.gpg ".
+      "--keyserver pgp.mit.edu --recv-keys ED444FF07D8D0BF6",'__display__');
    ($stdout,$stderr)=$handle->cmd("sudo apt update",'__display__');
-   ($stdout,$stderr)=$handle->cmd(
-       "sudo apt-get -o Dpkg::Progress=true -y install git debootstrap",
-       3600,'__display__');
-   if ($stderr) {
+   if ($stderr && $stderr!~/WARNING/) {
       print "Kali Linux Instruction Set cmd ERROR!: $stderr at Line".
          __LINE__."\n";
       Net::FullAuto::FA_Core::cleanup();
    }
-   ($stdout,$stderr)=$handle->cmd("sudo ln -sf ".
-       "/usr/share/debootstrap/scripts/{wheezy,sana}");
    # BUILDING uses Jazmine Figlet Font
    my $install_kali=<<'END';
 
@@ -155,108 +159,11 @@ my $configure_kalilinux=sub {
    (The Kali Linux™ Project is **NOT** a sponsor of the FullAuto© Project.)
 END
    print $install_kali;sleep 10;
-   ($stdout,$stderr)=$handle->cmd('git clone '.
-      "https://github.com/offensive-security/kali-cloud-build.git 2>&1",
-      3600,'__display__');
-   if ($stderr) {
-      print "Kali Linux Instruction Set cmd ERROR!: $stderr at Line".
-         __LINE__."\n";
-      Net::FullAuto::FA_Core::cleanup();
-   }
-   ($stdout,$stderr)=$handle->cwd("kali-cloud-build");
-   my $sk='';my $ak='';
-   unless (exists $main::aws->{access_id}) {
-      open(CF,"$ENV{HOME}/.aws/credentials");
-      while (my $line=<CF>) {
-         if ($line=~/^aws_access_key_id *= *(.*)\s*/) {
-            $ak=$1;
-         } elsif ($line=~/^aws_secret_access_key *= *(.*)\s*/) {
-            $sk=$1;
-         }
-      }
-      close CF;
-   } else {
-      $ak=$main::aws->{access_id};
-      $sk=$main::aws->{secret_key};
-   }
-   my $getownerid='aws ec2 describe-security-groups --filters '.
-                  'Name="description",Values="default VPC security group"';
-   my ($hash,$output,$error)=('','','');
-   ($hash,$output,$error)=run_aws_cmd($getownerid);
-   if ($error) {
-      print "Kali Linux Instruction Set aws cmd ERROR!: $error at Line".
-         __LINE__."\n";
-      Net::FullAuto::FA_Core::cleanup();
-   }
-   my $getkaliimages='aws ec2 describe-images --filters Name=owner-id,Values='
-                    .$hash->{SecurityGroups}->[0]->{OwnerId};
-   ($hash,$output,$error)=run_aws_cmd($getkaliimages);
-   if (-1<$#{$hash->{Images}}) {
-      foreach my $image (@{$hash->{Images}}) {
-         next if -1==index $image->{Name},'kali-kali-amd';
-         ($hash,$output,$error)=run_aws_cmd(
-            "aws ec2 deregister-image --image-id ".$image->{ImageId});
-         if ($error) {
-            print "Kali Linux Instruction Set aws cmd ERROR!: $error at Line".
-               __LINE__."\n";
-            Net::FullAuto::FA_Core::cleanup();
-         }
-         ($hash,$output,$error)=run_aws_cmd(
-            "aws ec2 delete-snapshot --snapshot-id ".
-            $image->{BlockDeviceMappings}->[0]->{Ebs}->{SnapshotId});
-         if ($error) {
-            print "Kali Linux Instruction Set aws cmd ERROR!: $error at Line".
-               __LINE__."\n";
-            Net::FullAuto::FA_Core::cleanup();
-         }
-      }
-   }
-   ($stdout,$stderr)=$handle->cmd(
-      "sudo ./kali-cloud-build ec2 --secret-key $sk --access-key $ak",
-      3600,'__display__');
-   my @lastfew=();
-   foreach my $line (reverse split "\n", $stderr) {
-      chomp($line=~tr/\0-\11\13-\37\177-\377//d);
-      $line=~s/^......(.*)...$/$1/;
-      unshift @lastfew, $line;
-      last if $line=~/Unable to register an AMI/;
-   }
-   my $lastfew=join "\n",@lastfew;
-   my ($nm,$arch,$kern,$snap,$sz,$del,$typ)=('','','','','','','');
-   my $r=qr/['](.*?)[']/;
-   $lastfew=~
-      /^.*?$r.*cture $r.*rnel $r.*shot ['](.*?)[:](.*?):(.*?):(.*?)['].*$/s;
-   $nm=$1;$arch=$2;$kern=$3;$snap=$4;$sz=$5;$del=$6;$typ=$7;
-   print "NM=$nm and ARCH=$arch and TYP=$typ\n";
-   my $rd=$main::aws->{$server_type}->[0]->[0]->{RootDeviceName};
-   my $reg_cmd="aws ec2 register-image --name '".$nm."' --description '' ".
-         "--architecture '".$arch."' --kernel-id '".$kern."' --root-device".
-         "-name '".$rd."' --block-device-mappings \"[{\\\"DeviceName\\\":".
-         "\\\"".$rd."\\\",\\\"Ebs\\\":{\\\"SnapshotId\\\":\\\"".$snap.
-         "\\\",\\\"VolumeSize\\\":$sz,\\\"DeleteOnTermination\\\":$del".
-         ",\\\"VolumeType\\\":\\\"$typ\\\"}}]\"";
-   ($hash,$output,$error)=run_aws_cmd($reg_cmd);
-   if ($error) {
-      print "Kali Linux Instruction Set aws cmd ERROR!: $error at Line".
-         __LINE__."\n";
-      Net::FullAuto::FA_Core::cleanup();
-   }
-   my $i=$hash->{ImageId};
-   my $pemfile=$pem_file;
-   $pemfile=~s/\.pem\s*$//s;
-   my $type=$main::aws->{kali}->{type};
-   #$type=~s/^t2/t1/;
-   #$type=~s/^m2/m1/;
-   #$type=~s/^m3/m1/;
-   my $kali=$main::aws->{kali}->{kali};
-   my $s=$main::aws->{fullauto}->
-      {NetworkInterfaces}->[0]->{SubnetId}||'';
-   my $g=get_aws_security_id('KaliLinuxSecurityGroup');
-   my $c="aws ec2 run-instances --image-id $i --count 1 ".
-      "--instance-type $type --key-name $pemfile ".
-      "--security-group-ids $g --subnet-id $s";
-   launch_server('Kali.org',1,$kali,'root',$c,
-                   $install_dashboard_on_kalilinux);
+   ($stdout,$stderr)=$handle->cmd("sudo git clone ".
+      "https://github.com/LionSec/katoolin.git",'__display__');
+   ($stdout,$stderr)=$handle->cmd("sudo cp katoolin/katoolin.py ".
+      "/usr/bin/katoolin",'__display__');
+   $install_dashboard_on_kalilinux->($_[0],$_[1],$_[2],$handle);
 
 };
 
