@@ -189,11 +189,7 @@ if ($do==1) {
          "resourceType=\'Unspecified\',requireAccess=\'Script\']\" ".
          "/commit:apphost",'__display__');
       ($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
-      ($stdout,$stderr)=$handle->cmd("touch CGI_Script.bat",'__display__');
-      $cyglocb=~s/\\/\\x5C/g;
-      ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script.bat");
-      ($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
-      ($stdout,$stderr)=$handle->cmd("touch CGI_Script");
+      ($stdout,$stderr)=$handle->cmd("touch CGI_Script.bat");
       #
       # echo-ing/streaming files over ssh can be tricky. Use echo -e
       #          and replace these characters with thier HEX
@@ -205,6 +201,7 @@ if ($do==1) {
       #          "  -   \\x22     \  -  \\x5C
       #          $  -   \\x24
       #
+      $cyglocb=~s/\\/\\x5C/g;
       my $content=<<END;
 $cyglocb\\x5Cbin\\x5Cbash -lc \\x22/bin/perl \\x251 \\x252\\x22
 END
